#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# homepage			: http://www.ibh.de/~ellguth/xfce4-wmdock-plugin.html
# source location	: http://www.ibh.de/~ellguth/develop/xfce4-wmdock-plugin-0.3.1.tar.gz
# last revised       : 15.09.2008

softname='xfce4-wmdock-plugin'
softversion='0.3.2'
packageversion='1fb'

arch='i486'
cpu='i686'

prefix=/usr

# log
(

# parameters needed for the build process
buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.gz"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://www.ibh.de/~ellguth/develop/$softname-$softversion.tar.gz

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc 
                   |-----handy-ruler------------------------------------------------------|
xfce4-wmdock-plugin: xfce4-wmdock-plugin (Dockapps on the XFCE desktop)
xfce4-wmdock-plugin:
xfce4-wmdock-plugin: It integrates the dockapps into a panel, closely resembling the  
xfce4-wmdock-plugin: look and feel of the WindowMaker dock or clip, respectively.
xfce4-wmdock-plugin: 
xfce4-wmdock-plugin: 
xfce4-wmdock-plugin: 
xfce4-wmdock-plugin:
xfce4-wmdock-plugin:
xfce4-wmdock-plugin:
xfce4-wmdock-plugin:
EOF

# check if source is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xzvf $srcpkg
cd $src	

# build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
    
./configure \
	--program-prefix="" \
	--program-suffix="" \
	--prefix="/usr" \
	--sysconfdir="/etc" \
	--localstatedir="/var" \
	--mandir="/usr/man" \
	--infodir="/usr/info" \
	--enable-static="no" \
	--enable-shared="yes" \
	--build=$arch-slackware-linux || exit

make DESTDIR=$dest
make install DESTDIR=$dest
   
# add 'default' files
	cd $src
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      AUTHORS COPYING ChangeLog INSTALL NEWS README TODO\
      $dest/usr/doc/$softname-$softversion
	
# strip executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# SalixBuild
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# md5sum signature
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "atk,cairo,e2fsprogs,expat,fontconfig,freetype,glib2,gtk+2,\
libICE,libSM,libX11,libXau,libXcomposite,libXcursor,libXdamage,\
libXdmcp,libXext,libXfixes,libXi,libXinerama,libXrandr,libXrender,\
libXres,libpng,libwnck,libxcb,pango,pixman,startup-notification,xfce,zlib" > $package.dep

# generate source file
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/divers/salix/xfce4_wmdock_plugin/build-xfce4-wmdock-plugin.sh > $package.src
echo $source >>$package.src

# erase 
rm -rf $src
rm -rf $dest

# log
) 2>&1 | tee "$softname-$softversion-build.log"
